@@ -8,7 +8,7 @@ from tornado import ioloop
 from tornado.concurrent import Future
 
 
-version_tuple = (0, 7)
+version_tuple = (0, 8)
 
 version = '.'.join(map(str, version_tuple))
 """Current version of Toro."""
@@ -73,10 +73,6 @@ class _TimeoutFuture(Future):
         self._cancel_timeout()
         super(_TimeoutFuture, self).set_exception(exception)
 
-    def _done_callback(self, _):
-        if not self.done():
-            self.set_result(None)
-
     def _cancel_timeout(self):
         if self._timeout_handle:
             self.io_loop.remove_timeout(self._timeout_handle)
